==> mined_2000.9.orig.tar.gz: mined-2000.9.orig/src/casespec.h <==
	{0x0049, {0x0069, 0x0307}, {0x0049}, {0x0049}, 0 | U_cond_lt | U_cond_More_Above},
	{0x0049, {0x0131}, {0x0049}, {0x0049}, 0 | U_cond_az | U_cond_Not_Before_Dot},
	{0x0049, {0x0131}, {0x0049}, {0x0049}, 0 | U_cond_tr | U_cond_Not_Before_Dot},
	{0x004A, {0x006A, 0x0307}, {0x004A}, {0x004A}, 0 | U_cond_lt | U_cond_More_Above},
	{0x0069, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_az},
	{0x0069, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_tr},
	{0x00CC, {0x0069, 0x0307, 0x0300}, {0x00CC}, {0x00CC}, 0 | U_cond_lt},
	{0x00CD, {0x0069, 0x0307, 0x0301}, {0x00CD}, {0x00CD}, 0 | U_cond_lt},
	{0x00DF, {0x00DF}, {0x0053, 0x0073}, {0x0053, 0x0053}, 0},
	{0x0128, {0x0069, 0x0307, 0x0303}, {0x0128}, {0x0128}, 0 | U_cond_lt},
	{0x012E, {0x012F, 0x0307}, {0x012E}, {0x012E}, 0 | U_cond_lt | U_cond_More_Above},
	{0x0130, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_az},
	{0x0130, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_tr},
	{0x0130, {0x0069, 0x0307}, {0x0130}, {0x0130}, 0},
	{0x0149, {0x0149}, {0x02BC, 0x004E}, {0x02BC, 0x004E}, 0},
	{0x01F0, {0x01F0}, {0x004A, 0x030C}, {0x004A, 0x030C}, 0},
	{0x0307, {0}, {0x0307}, {0x0307}, 0 | U_cond_az | U_cond_After_Soft_Dotted},
	{0x0307, {0}, {0x0307}, {0x0307}, 0 | U_cond_tr | U_cond_After_Soft_Dotted},
	{0x0307, {0x0307}, {0}, {0}, 0 | U_cond_lt | U_cond_After_Soft_Dotted},
	{0x0390, {0x0390}, {0x0399, 0x0308, 0x0301}, {0x0399, 0x0308, 0x0301}, 0},
	{0x03A3, {0x03C2}, {0x03A3}, {0x03A3}, 0 | U_cond_Final_Sigma},
	{0x03B0, {0x03B0}, {0x03A5, 0x0308, 0x0301}, {0x03A5, 0x0308, 0x0301}, 0},
	{0x0587, {0x0587}, {0x0535, 0x0582}, {0x0535, 0x0552}, 0},
	{0x1E96, {0x1E96}, {0x0048, 0x0331}, {0x0048, 0x0331}, 0},
	{0x1E97, {0x1E97}, {0x0054, 0x0308}, {0x0054, 0x0308}, 0},
	{0x1E98, {0x1E98}, {0x0057, 0x030A}, {0x0057, 0x030A}, 0},
	{0x1E99, {0x1E99}, {0x0059, 0x030A}, {0x0059, 0x030A}, 0},
	{0x1E9A, {0x1E9A}, {0x0041, 0x02BE}, {0x0041, 0x02BE}, 0},
	{0x1F50, {0x1F50}, {0x03A5, 0x0313}, {0x03A5, 0x0313}, 0},
	{0x1F52, {0x1F52}, {0x03A5, 0x0313, 0x0300}, {0x03A5, 0x0313, 0x0300}, 0},
	{0x1F54, {0x1F54}, {0x03A5, 0x0313, 0x0301}, {0x03A5, 0x0313, 0x0301}, 0},
	{0x1F56, {0x1F56}, {0x03A5, 0x0313, 0x0342}, {0x03A5, 0x0313, 0x0342}, 0},
	{0x1F80, {0x1F80}, {0x1F88}, {0x1F08, 0x0399}, 0},
	{0x1F81, {0x1F81}, {0x1F89}, {0x1F09, 0x0399}, 0},
	{0x1F82, {0x1F82}, {0x1F8A}, {0x1F0A, 0x0399}, 0},
	{0x1F83, {0x1F83}, {0x1F8B}, {0x1F0B, 0x0399}, 0},
	{0x1F84, {0x1F84}, {0x1F8C}, {0x1F0C, 0x0399}, 0},
	{0x1F85, {0x1F85}, {0x1F8D}, {0x1F0D, 0x0399}, 0},
	{0x1F86, {0x1F86}, {0x1F8E}, {0x1F0E, 0x0399}, 0},
	{0x1F87, {0x1F87}, {0x1F8F}, {0x1F0F, 0x0399}, 0},
	{0x1F88, {0x1F80}, {0x1F88}, {0x1F08, 0x0399}, 0},
	{0x1F89, {0x1F81}, {0x1F89}, {0x1F09, 0x0399}, 0},
	{0x1F8A, {0x1F82}, {0x1F8A}, {0x1F0A, 0x0399}, 0},
	{0x1F8B, {0x1F83}, {0x1F8B}, {0x1F0B, 0x0399}, 0},
	{0x1F8C, {0x1F84}, {0x1F8C}, {0x1F0C, 0x0399}, 0},
	{0x1F8D, {0x1F85}, {0x1F8D}, {0x1F0D, 0x0399}, 0},
	{0x1F8E, {0x1F86}, {0x1F8E}, {0x1F0E, 0x0399}, 0},
	{0x1F8F, {0x1F87}, {0x1F8F}, {0x1F0F, 0x0399}, 0},
	{0x1F90, {0x1F90}, {0x1F98}, {0x1F28, 0x0399}, 0},
	{0x1F91, {0x1F91}, {0x1F99}, {0x1F29, 0x0399}, 0},
	{0x1F92, {0x1F92}, {0x1F9A}, {0x1F2A, 0x0399}, 0},
	{0x1F93, {0x1F93}, {0x1F9B}, {0x1F2B, 0x0399}, 0},
	{0x1F94, {0x1F94}, {0x1F9C}, {0x1F2C, 0x0399}, 0},
	{0x1F95, {0x1F95}, {0x1F9D}, {0x1F2D, 0x0399}, 0},
	{0x1F96, {0x1F96}, {0x1F9E}, {0x1F2E, 0x0399}, 0},
	{0x1F97, {0x1F97}, {0x1F9F}, {0x1F2F, 0x0399}, 0},
	{0x1F98, {0x1F90}, {0x1F98}, {0x1F28, 0x0399}, 0},
	{0x1F99, {0x1F91}, {0x1F99}, {0x1F29, 0x0399}, 0},
	{0x1F9A, {0x1F92}, {0x1F9A}, {0x1F2A, 0x0399}, 0},
	{0x1F9B, {0x1F93}, {0x1F9B}, {0x1F2B, 0x0399}, 0},
	{0x1F9C, {0x1F94}, {0x1F9C}, {0x1F2C, 0x0399}, 0},
	{0x1F9D, {0x1F95}, {0x1F9D}, {0x1F2D, 0x0399}, 0},
	{0x1F9E, {0x1F96}, {0x1F9E}, {0x1F2E, 0x0399}, 0},
	{0x1F9F, {0x1F97}, {0x1F9F}, {0x1F2F, 0x0399}, 0},
	{0x1FA0, {0x1FA0}, {0x1FA8}, {0x1F68, 0x0399}, 0},
	{0x1FA1, {0x1FA1}, {0x1FA9}, {0x1F69, 0x0399}, 0},
	{0x1FA2, {0x1FA2}, {0x1FAA}, {0x1F6A, 0x0399}, 0},
	{0x1FA3, {0x1FA3}, {0x1FAB}, {0x1F6B, 0x0399}, 0},
	{0x1FA4, {0x1FA4}, {0x1FAC}, {0x1F6C, 0x0399}, 0},
	{0x1FA5, {0x1FA5}, {0x1FAD}, {0x1F6D, 0x0399}, 0},
	{0x1FA6, {0x1FA6}, {0x1FAE}, {0x1F6E, 0x0399}, 0},
	{0x1FA7, {0x1FA7}, {0x1FAF}, {0x1F6F, 0x0399}, 0},
	{0x1FA8, {0x1FA0}, {0x1FA8}, {0x1F68, 0x0399}, 0},
	{0x1FA9, {0x1FA1}, {0x1FA9}, {0x1F69, 0x0399}, 0},
	{0x1FAA, {0x1FA2}, {0x1FAA}, {0x1F6A, 0x0399}, 0},
	{0x1FAB, {0x1FA3}, {0x1FAB}, {0x1F6B, 0x0399}, 0},
	{0x1FAC, {0x1FA4}, {0x1FAC}, {0x1F6C, 0x0399}, 0},
	{0x1FAD, {0x1FA5}, {0x1FAD}, {0x1F6D, 0x0399}, 0},
	{0x1FAE, {0x1FA6}, {0x1FAE}, {0x1F6E, 0x0399}, 0},
	{0x1FAF, {0x1FA7}, {0x1FAF}, {0x1F6F, 0x0399}, 0},
	{0x1FB2, {0x1FB2}, {0x1FBA, 0x0345}, {0x1FBA, 0x0399}, 0},
	{0x1FB3, {0x1FB3}, {0x1FBC}, {0x0391, 0x0399}, 0},
	{0x1FB4, {0x1FB4}, {0x0386, 0x0345}, {0x0386, 0x0399}, 0},
	{0x1FB6, {0x1FB6}, {0x0391, 0x0342}, {0x0391, 0x0342}, 0},
	{0x1FB7, {0x1FB7}, {0x0391, 0x0342, 0x0345}, {0x0391, 0x0342, 0x0399}, 0},
	{0x1FBC, {0x1FB3}, {0x1FBC}, {0x0391, 0x0399}, 0},
	{0x1FC2, {0x1FC2}, {0x1FCA, 0x0345}, {0x1FCA, 0x0399}, 0},
	{0x1FC3, {0x1FC3}, {0x1FCC}, {0x0397, 0x0399}, 0},
	{0x1FC4, {0x1FC4}, {0x0389, 0x0345}, {0x0389, 0x0399}, 0},
	{0x1FC6, {0x1FC6}, {0x0397, 0x0342}, {0x0397, 0x0342}, 0},
	{0x1FC7, {0x1FC7}, {0x0397, 0x0342, 0x0345}, {0x0397, 0x0342, 0x0399}, 0},
	{0x1FCC, {0x1FC3}, {0x1FCC}, {0x0397, 0x0399}, 0},
	{0x1FD2, {0x1FD2}, {0x0399, 0x0308, 0x0300}, {0x0399, 0x0308, 0x0300}, 0},
	{0x1FD3, {0x1FD3}, {0x0399, 0x0308, 0x0301}, {0x0399, 0x0308, 0x0301}, 0},
	{0x1FD6, {0x1FD6}, {0x0399, 0x0342}, {0x0399, 0x0342}, 0},
	{0x1FD7, {0x1FD7}, {0x0399, 0x0308, 0x0342}, {0x0399, 0x0308, 0x0342}, 0},
	{0x1FE2, {0x1FE2}, {0x03A5, 0x0308, 0x0300}, {0x03A5, 0x0308, 0x0300}, 0},
	{0x1FE3, {0x1FE3}, {0x03A5, 0x0308, 0x0301}, {0x03A5, 0x0308, 0x0301}, 0},
	{0x1FE4, {0x1FE4}, {0x03A1, 0x0313}, {0x03A1, 0x0313}, 0},
	{0x1FE6, {0x1FE6}, {0x03A5, 0x0342}, {0x03A5, 0x0342}, 0},
	{0x1FE7, {0x1FE7}, {0x03A5, 0x0308, 0x0342}, {0x03A5, 0x0308, 0x0342}, 0},
	{0x1FF2, {0x1FF2}, {0x1FFA, 0x0345}, {0x1FFA, 0x0399}, 0},
	{0x1FF3, {0x1FF3}, {0x1FFC}, {0x03A9, 0x0399}, 0},
	{0x1FF4, {0x1FF4}, {0x038F, 0x0345}, {0x038F, 0x0399}, 0},
	{0x1FF6, {0x1FF6}, {0x03A9, 0x0342}, {0x03A9, 0x0342}, 0},
	{0x1FF7, {0x1FF7}, {0x03A9, 0x0342, 0x0345}, {0x03A9, 0x0342, 0x0399}, 0},
	{0x1FFC, {0x1FF3}, {0x1FFC}, {0x03A9, 0x0399}, 0},
	{0xFB00, {0xFB00}, {0x0046, 0x0066}, {0x0046, 0x0046}, 0},
	{0xFB01, {0xFB01}, {0x0046, 0x0069}, {0x0046, 0x0049}, 0},
	{0xFB02, {0xFB02}, {0x0046, 0x006C}, {0x0046, 0x004C}, 0},
	{0xFB03, {0xFB03}, {0x0046, 0x0066, 0x0069}, {0x0046, 0x0046, 0x0049}, 0},
	{0xFB04, {0xFB04}, {0x0046, 0x0066, 0x006C}, {0x0046, 0x0046, 0x004C}, 0},
	{0xFB05, {0xFB05}, {0x0053, 0x0074}, {0x0053, 0x0054}, 0},
	{0xFB06, {0xFB06}, {0x0053, 0x0074}, {0x0053, 0x0054}, 0},
	{0xFB13, {0xFB13}, {0x0544, 0x0576}, {0x0544, 0x0546}, 0},
	{0xFB14, {0xFB14}, {0x0544, 0x0565}, {0x0544, 0x0535}, 0},
	{0xFB15, {0xFB15}, {0x0544, 0x056B}, {0x0544, 0x053B}, 0},
	{0xFB16, {0xFB16}, {0x054E, 0x0576}, {0x054E, 0x0546}, 0},
	{0xFB17, {0xFB17}, {0x0544, 0x056D}, {0x0544, 0x053D}, 0},

==> mined_2000.10.orig.tar.gz: mined-2000.10.orig/src/casespec.h <==
	{0x0049, {0x0069, 0x0307}, {0x0049}, {0x0049}, 0 | U_cond_lt | U_cond_More_Above},
	{0x0049, {0x0131}, {0x0049}, {0x0049}, 0 | U_cond_az | U_cond_Not_Before_Dot},
	{0x0049, {0x0131}, {0x0049}, {0x0049}, 0 | U_cond_tr | U_cond_Not_Before_Dot},
	{0x004A, {0x006A, 0x0307}, {0x004A}, {0x004A}, 0 | U_cond_lt | U_cond_More_Above},
	{0x0069, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_az},
	{0x0069, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_tr},
	{0x00CC, {0x0069, 0x0307, 0x0300}, {0x00CC}, {0x00CC}, 0 | U_cond_lt},
	{0x00CD, {0x0069, 0x0307, 0x0301}, {0x00CD}, {0x00CD}, 0 | U_cond_lt},
	{0x00DF, {0x00DF}, {0x0053, 0x0073}, {0x0053, 0x0053}, 0},
	{0x0128, {0x0069, 0x0307, 0x0303}, {0x0128}, {0x0128}, 0 | U_cond_lt},
	{0x012E, {0x012F, 0x0307}, {0x012E}, {0x012E}, 0 | U_cond_lt | U_cond_More_Above},
	{0x0130, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_az},
	{0x0130, {0x0069}, {0x0130}, {0x0130}, 0 | U_cond_tr},
	{0x0130, {0x0069, 0x0307}, {0x0130}, {0x0130}, 0},
	{0x0149, {0x0149}, {0x02BC, 0x004E}, {0x02BC, 0x004E}, 0},
	{0x01F0, {0x01F0}, {0x004A, 0x030C}, {0x004A, 0x030C}, 0},
	{0x0307, {0}, {0x0307}, {0x0307}, 0 | U_cond_az | U_cond_After_I},
	{0x0307, {0}, {0x0307}, {0x0307}, 0 | U_cond_tr | U_cond_After_I},
	{0x0307, {0x0307}, {0}, {0}, 0 | U_cond_lt | U_cond_After_Soft_Dotted},
	{0x0390, {0x0390}, {0x0399, 0x0308, 0x0301}, {0x0399, 0x0308, 0x0301}, 0},
	{0x03A3, {0x03C2}, {0x03A3}, {0x03A3}, 0 | U_cond_Final_Sigma},
	{0x03B0, {0x03B0}, {0x03A5, 0x0308, 0x0301}, {0x03A5, 0x0308, 0x0301}, 0},
	{0x0587, {0x0587}, {0x0535, 0x0582}, {0x0535, 0x0552}, 0},
	{0x1E96, {0x1E96}, {0x0048, 0x0331}, {0x0048, 0x0331}, 0},
	{0x1E97, {0x1E97}, {0x0054, 0x0308}, {0x0054, 0x0308}, 0},
	{0x1E98, {0x1E98}, {0x0057, 0x030A}, {0x0057, 0x030A}, 0},
	{0x1E99, {0x1E99}, {0x0059, 0x030A}, {0x0059, 0x030A}, 0},
	{0x1E9A, {0x1E9A}, {0x0041, 0x02BE}, {0x0041, 0x02BE}, 0},
	{0x1F50, {0x1F50}, {0x03A5, 0x0313}, {0x03A5, 0x0313}, 0},
	{0x1F52, {0x1F52}, {0x03A5, 0x0313, 0x0300}, {0x03A5, 0x0313, 0x0300}, 0},
	{0x1F54, {0x1F54}, {0x03A5, 0x0313, 0x0301}, {0x03A5, 0x0313, 0x0301}, 0},
	{0x1F56, {0x1F56}, {0x03A5, 0x0313, 0x0342}, {0x03A5, 0x0313, 0x0342}, 0},
	{0x1F80, {0x1F80}, {0x1F88}, {0x1F08, 0x0399}, 0},
	{0x1F81, {0x1F81}, {0x1F89}, {0x1F09, 0x0399}, 0},
	{0x1F82, {0x1F82}, {0x1F8A}, {0x1F0A, 0x0399}, 0},
	{0x1F83, {0x1F83}, {0x1F8B}, {0x1F0B, 0x0399}, 0},
	{0x1F84, {0x1F84}, {0x1F8C}, {0x1F0C, 0x0399}, 0},
	{0x1F85, {0x1F85}, {0x1F8D}, {0x1F0D, 0x0399}, 0},
	{0x1F86, {0x1F86}, {0x1F8E}, {0x1F0E, 0x0399}, 0},
	{0x1F87, {0x1F87}, {0x1F8F}, {0x1F0F, 0x0399}, 0},
	{0x1F88, {0x1F80}, {0x1F88}, {0x1F08, 0x0399}, 0},
	{0x1F89, {0x1F81}, {0x1F89}, {0x1F09, 0x0399}, 0},
	{0x1F8A, {0x1F82}, {0x1F8A}, {0x1F0A, 0x0399}, 0},
	{0x1F8B, {0x1F83}, {0x1F8B}, {0x1F0B, 0x0399}, 0},
	{0x1F8C, {0x1F84}, {0x1F8C}, {0x1F0C, 0x0399}, 0},
	{0x1F8D, {0x1F85}, {0x1F8D}, {0x1F0D, 0x0399}, 0},
	{0x1F8E, {0x1F86}, {0x1F8E}, {0x1F0E, 0x0399}, 0},
	{0x1F8F, {0x1F87}, {0x1F8F}, {0x1F0F, 0x0399}, 0},
	{0x1F90, {0x1F90}, {0x1F98}, {0x1F28, 0x0399}, 0},
	{0x1F91, {0x1F91}, {0x1F99}, {0x1F29, 0x0399}, 0},
	{0x1F92, {0x1F92}, {0x1F9A}, {0x1F2A, 0x0399}, 0},
	{0x1F93, {0x1F93}, {0x1F9B}, {0x1F2B, 0x0399}, 0},
	{0x1F94, {0x1F94}, {0x1F9C}, {0x1F2C, 0x0399}, 0},
	{0x1F95, {0x1F95}, {0x1F9D}, {0x1F2D, 0x0399}, 0},
	{0x1F96, {0x1F96}, {0x1F9E}, {0x1F2E, 0x0399}, 0},
	{0x1F97, {0x1F97}, {0x1F9F}, {0x1F2F, 0x0399}, 0},
	{0x1F98, {0x1F90}, {0x1F98}, {0x1F28, 0x0399}, 0},
	{0x1F99, {0x1F91}, {0x1F99}, {0x1F29, 0x0399}, 0},
	{0x1F9A, {0x1F92}, {0x1F9A}, {0x1F2A, 0x0399}, 0},
	{0x1F9B, {0x1F93}, {0x1F9B}, {0x1F2B, 0x0399}, 0},
	{0x1F9C, {0x1F94}, {0x1F9C}, {0x1F2C, 0x0399}, 0},
	{0x1F9D, {0x1F95}, {0x1F9D}, {0x1F2D, 0x0399}, 0},
	{0x1F9E, {0x1F96}, {0x1F9E}, {0x1F2E, 0x0399}, 0},
	{0x1F9F, {0x1F97}, {0x1F9F}, {0x1F2F, 0x0399}, 0},
	{0x1FA0, {0x1FA0}, {0x1FA8}, {0x1F68, 0x0399}, 0},
	{0x1FA1, {0x1FA1}, {0x1FA9}, {0x1F69, 0x0399}, 0},
	{0x1FA2, {0x1FA2}, {0x1FAA}, {0x1F6A, 0x0399}, 0},
	{0x1FA3, {0x1FA3}, {0x1FAB}, {0x1F6B, 0x0399}, 0},
	{0x1FA4, {0x1FA4}, {0x1FAC}, {0x1F6C, 0x0399}, 0},
	{0x1FA5, {0x1FA5}, {0x1FAD}, {0x1F6D, 0x0399}, 0},
	{0x1FA6, {0x1FA6}, {0x1FAE}, {0x1F6E, 0x0399}, 0},
	{0x1FA7, {0x1FA7}, {0x1FAF}, {0x1F6F, 0x0399}, 0},
	{0x1FA8, {0x1FA0}, {0x1FA8}, {0x1F68, 0x0399}, 0},
	{0x1FA9, {0x1FA1}, {0x1FA9}, {0x1F69, 0x0399}, 0},
	{0x1FAA, {0x1FA2}, {0x1FAA}, {0x1F6A, 0x0399}, 0},
	{0x1FAB, {0x1FA3}, {0x1FAB}, {0x1F6B, 0x0399}, 0},
	{0x1FAC, {0x1FA4}, {0x1FAC}, {0x1F6C, 0x0399}, 0},
	{0x1FAD, {0x1FA5}, {0x1FAD}, {0x1F6D, 0x0399}, 0},
	{0x1FAE, {0x1FA6}, {0x1FAE}, {0x1F6E, 0x0399}, 0},
	{0x1FAF, {0x1FA7}, {0x1FAF}, {0x1F6F, 0x0399}, 0},
	{0x1FB2, {0x1FB2}, {0x1FBA, 0x0345}, {0x1FBA, 0x0399}, 0},
	{0x1FB3, {0x1FB3}, {0x1FBC}, {0x0391, 0x0399}, 0},
	{0x1FB4, {0x1FB4}, {0x0386, 0x0345}, {0x0386, 0x0399}, 0},
	{0x1FB6, {0x1FB6}, {0x0391, 0x0342}, {0x0391, 0x0342}, 0},
	{0x1FB7, {0x1FB7}, {0x0391, 0x0342, 0x0345}, {0x0391, 0x0342, 0x0399}, 0},
	{0x1FBC, {0x1FB3}, {0x1FBC}, {0x0391, 0x0399}, 0},
	{0x1FC2, {0x1FC2}, {0x1FCA, 0x0345}, {0x1FCA, 0x0399}, 0},
	{0x1FC3, {0x1FC3}, {0x1FCC}, {0x0397, 0x0399}, 0},
	{0x1FC4, {0x1FC4}, {0x0389, 0x0345}, {0x0389, 0x0399}, 0},
	{0x1FC6, {0x1FC6}, {0x0397, 0x0342}, {0x0397, 0x0342}, 0},
	{0x1FC7, {0x1FC7}, {0x0397, 0x0342, 0x0345}, {0x0397, 0x0342, 0x0399}, 0},
	{0x1FCC, {0x1FC3}, {0x1FCC}, {0x0397, 0x0399}, 0},
	{0x1FD2, {0x1FD2}, {0x0399, 0x0308, 0x0300}, {0x0399, 0x0308, 0x0300}, 0},
	{0x1FD3, {0x1FD3}, {0x0399, 0x0308, 0x0301}, {0x0399, 0x0308, 0x0301}, 0},
	{0x1FD6, {0x1FD6}, {0x0399, 0x0342}, {0x0399, 0x0342}, 0},
	{0x1FD7, {0x1FD7}, {0x0399, 0x0308, 0x0342}, {0x0399, 0x0308, 0x0342}, 0},
	{0x1FE2, {0x1FE2}, {0x03A5, 0x0308, 0x0300}, {0x03A5, 0x0308, 0x0300}, 0},
	{0x1FE3, {0x1FE3}, {0x03A5, 0x0308, 0x0301}, {0x03A5, 0x0308, 0x0301}, 0},
	{0x1FE4, {0x1FE4}, {0x03A1, 0x0313}, {0x03A1, 0x0313}, 0},
	{0x1FE6, {0x1FE6}, {0x03A5, 0x0342}, {0x03A5, 0x0342}, 0},
	{0x1FE7, {0x1FE7}, {0x03A5, 0x0308, 0x0342}, {0x03A5, 0x0308, 0x0342}, 0},
	{0x1FF2, {0x1FF2}, {0x1FFA, 0x0345}, {0x1FFA, 0x0399}, 0},
	{0x1FF3, {0x1FF3}, {0x1FFC}, {0x03A9, 0x0399}, 0},
	{0x1FF4, {0x1FF4}, {0x038F, 0x0345}, {0x038F, 0x0399}, 0},
	{0x1FF6, {0x1FF6}, {0x03A9, 0x0342}, {0x03A9, 0x0342}, 0},
	{0x1FF7, {0x1FF7}, {0x03A9, 0x0342, 0x0345}, {0x03A9, 0x0342, 0x0399}, 0},
	{0x1FFC, {0x1FF3}, {0x1FFC}, {0x03A9, 0x0399}, 0},
	{0xFB00, {0xFB00}, {0x0046, 0x0066}, {0x0046, 0x0046}, 0},
	{0xFB01, {0xFB01}, {0x0046, 0x0069}, {0x0046, 0x0049}, 0},
	{0xFB02, {0xFB02}, {0x0046, 0x006C}, {0x0046, 0x004C}, 0},
	{0xFB03, {0xFB03}, {0x0046, 0x0066, 0x0069}, {0x0046, 0x0046, 0x0049}, 0},
	{0xFB04, {0xFB04}, {0x0046, 0x0066, 0x006C}, {0x0046, 0x0046, 0x004C}, 0},
	{0xFB05, {0xFB05}, {0x0053, 0x0074}, {0x0053, 0x0054}, 0},
	{0xFB06, {0xFB06}, {0x0053, 0x0074}, {0x0053, 0x0054}, 0},
	{0xFB13, {0xFB13}, {0x0544, 0x0576}, {0x0544, 0x0546}, 0},
	{0xFB14, {0xFB14}, {0x0544, 0x0565}, {0x0544, 0x0535}, 0},
	{0xFB15, {0xFB15}, {0x0544, 0x056B}, {0x0544, 0x053B}, 0},
	{0xFB16, {0xFB16}, {0x054E, 0x0576}, {0x054E, 0x0546}, 0},
	{0xFB17, {0xFB17}, {0x0544, 0x056D}, {0x0544, 0x053D}, 0},
